pub struct Ats {
pub client: Client,
}Available on crate feature
requests only.Fields
client: ClientImplementations
Sourceimpl Ats
impl Ats
Sourcepub async fn post_candidates_push_candidate<'a>(
&'a self,
body: &Candidate,
) -> Result<Candidate, Error>
pub async fn post_candidates_push_candidate<'a>( &'a self, body: &Candidate, ) -> Result<Candidate, Error>
POST New Candidate
Pushes a candidate from an applicant tracking system directly into the Rippling onboarding flow. Please note, this endpoint is only available to applications integrating with OAuth2.0.
NOTE: This endpoint is NOT available for use with Rippling customer API Keys.
async fn example_ats_post_candidates_push_candidate() -> anyhow::Result<()> {
let client = rippling_base_api::Client::new_from_env();
let result: rippling_base_api::types::Candidate = client
.ats()
.post_candidates_push_candidate(&rippling_base_api::types::Candidate {
name: Some("some-string".to_string()),
email: Some("some-string".to_string()),
job_title: Some("some-string".to_string()),
phone_number: Some("some-string".to_string()),
candidate_id: Some("some-string".to_string()),
start_date: Some(chrono::Utc::now().date_naive()),
salary_unit: Some(rippling_base_api::types::SalaryUnit::PayPeriod),
salary_per_unit: Some(3.14 as f64),
signing_bonus: Some(3.14 as f64),
currency: Some("some-string".to_string()),
equity_shares: Some(4 as i64),
department: Some("some-string".to_string()),
employment_type: Some(rippling_base_api::types::CandidateEmploymentType::Temp),
work_location: Some("some-string".to_string()),
attachments: Some(vec![rippling_base_api::types::Attachments {
file_name: Some("some-string".to_string()),
file_url: Some("some-string".to_string()),
}]),
})
.await?;
println!("{:?}", result);
Ok(())
}Trait Implementations